@@ -32,8 +32,8 @@ void usage( void ) {
 unsigned int channels;
 
 // Interleaved buffers
-int sawi( void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
-          double streamTime, RtAudioStreamStatus status, void *data )
+int sawi( void *outputBuffer, void * /*inputBuffer*/, unsigned int nBufferFrames,
+          double /*streamTime*/, RtAudioStreamStatus status, void *data )
 {
   unsigned int i, j;
   extern unsigned int channels;
@@ -55,8 +55,8 @@ int sawi( void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
 }
 
 // Non-interleaved buffers
-int sawni( void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
-           double streamTime, RtAudioStreamStatus status, void *data )
+int sawni( void *outputBuffer, void * /*inputBuffer*/, unsigned int nBufferFrames,
+           double /*streamTime*/, RtAudioStreamStatus status, void *data )
 {
   unsigned int i, j;
   extern unsigned int channels;
@@ -79,8 +79,8 @@ int sawni( void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
   return 0;
 }
 
-int inout( void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
-           double streamTime, RtAudioStreamStatus status, void *data )
+int inout( void *outputBuffer, void *inputBuffer, unsigned int /*nBufferFrames*/,
+           double /*streamTime*/, RtAudioStreamStatus status, void *data )
 {
   // Since the number of input and output channels is equal, we can do
   // a simple buffer copy operation here.
@@ -128,6 +128,9 @@ int main( int argc, char *argv[] )
   oParams.nChannels = channels;
   oParams.firstChannel = oOffset;
 
+  if ( oDevice == 0 )
+    oParams.deviceId = dac.getDefaultOutputDevice();
+
   RtAudio::StreamOptions options;
   options.flags = RTAUDIO_HOG_DEVICE;
   try {
@@ -160,7 +163,7 @@ int main( int argc, char *argv[] )
     std::cout << "Playing again ... press <enter> to close the stream.\n";
     std::cin.get( input );
   }
-  catch ( RtError& e ) {
+  catch ( RtAudioError& e ) {
     e.printMessage();
     goto cleanup;
   }
@@ -180,7 +183,7 @@ int main( int argc, char *argv[] )
     std::cout << "\nPlaying ... press <enter> to stop.\n";
     std::cin.get( input );
   }
-  catch ( RtError& e ) {
+  catch ( RtAudioError& e ) {
     e.printMessage();
     goto cleanup;
   }
@@ -192,6 +195,8 @@ int main( int argc, char *argv[] )
   iParams.deviceId = iDevice;
   iParams.nChannels = channels;
   iParams.firstChannel = iOffset;
+  if ( iDevice == 0 )
+    iParams.deviceId = dac.getDefaultInputDevice();
   options.flags = RTAUDIO_NONINTERLEAVED;
   try {
     dac.openStream( &oParams, &iParams, RTAUDIO_SINT32, fs, &bufferFrames, &inout, (void *)&bufferBytes, &options );
@@ -216,7 +221,7 @@ int main( int argc, char *argv[] )
     std::cout << "\nRunning ... press <enter> to stop.\n";
     std::cin.get( input );
   }
-  catch ( RtError& e ) {
+  catch ( RtAudioError& e ) {
     e.printMessage();
   }
 
